@@ -42,13 +42,6 @@ def run(app_directory, listener_address=None, no_logs=False, running_describe=Fa
     # Identify the application root directory
     app_root_directory = app_directory or os.getcwd()
 
-    dbsupport_fname = join(app_root_directory, "dbsupport.py")
-    dbsupport = None
-    if exists(dbsupport_fname):
-        spec = importlib.util.spec_from_file_location("dbsupport", dbsupport_fname)
-        dbsupport = importlib.util.module_from_spec(spec)
-        spec.loader.exec_module(dbsupport)
-
     startup.setup_app("app_name", app_root_directory, no_logs)
 
     if running_describe:
@@ -72,10 +65,6 @@ def run(app_directory, listener_address=None, no_logs=False, running_describe=Fa
     if hasattr(cherrypy.engine, "signals"):
         cherrypy.engine.signals.subscribe()
     cherrypy.engine.subscribe("stop", lambda: os.chdir(startup_cwd))
-    if dbsupport:
-        print("** Setting up datbase")
-        cherrypy.engine.subscribe("start", dbsupport.setup_database)
-        cherrypy.engine.subscribe("stop", dbsupport.cleanup_database)
 
     cherrypy.engine.start()
     cherrypy.engine.block()
